==> gulp-lcov-to-html-0.0.3.tgz: package/lib/parser.js <==
var path, summarizeSection, trim,
  slice = [].slice;

path = require('path');

trim = function(v) {
  return v.trim();
};

summarizeSection = function(section) {
  var _, hit, info, ref, total;
  if (!((section.total != null) && (section.hit != null))) {
    total = hit = 0;
    ref = section.found;
    for (_ in ref) {
      info = ref[_];
      total++;
      if (info > 0 || info.hits > 0) {
        hit++;
      }
    }
    section.hit = hit;
    section.total = total;
  }
  if (total !== 0) {
    return section.percentage = Math.round(hit / total * 1000) / 10;
  } else {
    return section.percentage = -1;
  }
};

module.exports = function(data) {
  var _, base, base1, base2, blockNumber, branch, branchNumber, executionCount, file, fileName, functionData, hitCount, i, j, len, line, lineNumber, name, ref, ref1, ref2, ref3, ref4, ref5, ref6, sourceFiles, taken, testName, type, value;
  testName = null;
  sourceFiles = {};
  file = null;
  ref = data.split('\n').map(trim).filter(function(v) {
    return v.length > 0;
  });
  for (i = 0, len = ref.length; i < len; i++) {
    line = ref[i];
    ref1 = line.split(':'), type = ref1[0], value = ref1[1];
    if (!(type === "TN" || type === "SF") && (file == null)) {
      return null;
    }
    switch (type) {
      case "TN":
        testName = value;
        break;
      case "SF":
        if (file != null) {
          return null;
        }
        ref2 = value.split(path.sep), _ = 2 <= ref2.length ? slice.call(ref2, 0, j = ref2.length - 1) : (j = 0, []), fileName = ref2[j++];
        file = sourceFiles[value] != null ? sourceFiles[value] : sourceFiles[value] = {
          type: 'file',
          path: value,
          name: fileName,
          stats: {
            lines: {
              found: {}
            },
            branches: {
              found: {}
            },
            functions: {
              found: {}
            }
          }
        };
        break;
      case "FN":
        ref3 = value.split(',').map(trim), lineNumber = ref3[0], name = ref3[1];
        functionData = (base = file.stats.functions.found)[name] != null ? base[name] : base[name] = {};
        functionData.line = parseInt(lineNumber, 10);
        break;
      case "FNDA":
        ref4 = value.split(',').map(trim), executionCount = ref4[0], name = ref4[1];
        functionData = (base1 = file.stats.functions.found)[name] != null ? base1[name] : base1[name] = {};
        functionData.hits = parseInt(executionCount, 10);
        break;
      case "FNF":
        file.stats.functions.total = parseInt(value, 10);
        break;
      case "FNH":
        file.stats.functions.hit = parseInt(value, 10);
        break;
      case "BRDA":
        ref5 = value.split(',').map(trim), lineNumber = ref5[0], blockNumber = ref5[1], branchNumber = ref5[2], taken = ref5[3];
        branch = (base2 = file.stats.branches.found)[lineNumber] != null ? base2[lineNumber] : base2[lineNumber] = {};
        branch.block = blockNumber;
        branch.branch = branchNumber;
        branch.hits = taken;
        break;
      case "BRF":
        file.stats.branches.total = parseInt(value, 10);
        break;
      case "BRH":
        file.stats.branches.hit = parseInt(value, 10);
        break;
      case "DA":
        ref6 = value.split(',').map(trim), lineNumber = ref6[0], hitCount = ref6[1];
        file.stats.lines.found[lineNumber] = parseInt(hitCount, 10);
        break;
      case "LH":
        file.stats.lines.hit = parseInt(value, 10);
        break;
      case "LF":
        file.stats.lines.total = parseInt(value, 10);
        break;
      case "end_of_record":
        summarizeSection(file.stats.functions);
        summarizeSection(file.stats.branches);
        summarizeSection(file.stats.lines);
        file = null;
    }
  }
  return {
    name: testName,
    files: sourceFiles
  };
};

==> gulp-lcov-to-html-2.0.0.tgz: package/lib/parser.js <==
var path, summarizeSection, trim,
  slice = [].slice;

path = require('path');

trim = function(v) {
  return v.trim();
};

summarizeSection = function(section) {
  var _, hit, info, ref, total;
  if (!((section.total != null) && (section.hit != null))) {
    total = hit = 0;
    ref = section.found;
    for (_ in ref) {
      info = ref[_];
      total++;
      if (info > 0 || info.hits > 0) {
        hit++;
      }
    }
    section.hit = hit;
    section.total = total;
  }
  if (total !== 0) {
    return section.percentage = Math.round(hit / total * 1000) / 10;
  } else {
    return section.percentage = -1;
  }
};

module.exports = function(data, sourceFiles) {
  var _, base, base1, base2, blockNumber, branch, branchNumber, executionCount, file, fileName, functionData, hitCount, i, j, len, line, lineNumber, name, ref, ref1, ref2, ref3, ref4, ref5, ref6, taken, testName, type, value;
  testName = null;
  sourceFiles = sourceFiles || {};
  file = null;
  ref = data.split('\n').map(trim).filter(function(v) {
    return v.length > 0;
  });
  for (i = 0, len = ref.length; i < len; i++) {
    line = ref[i];
    ref1 = line.split(':'), type = ref1[0], value = ref1[1];
    if (!(type === "TN" || type === "SF") && (file == null)) {
      return null;
    }
    switch (type) {
      case "TN":
        testName = value;
        break;
      case "SF":
        if (file != null) {
          return null;
        }
        ref2 = value.split(path.sep), _ = 2 <= ref2.length ? slice.call(ref2, 0, j = ref2.length - 1) : (j = 0, []), fileName = ref2[j++];
        file = sourceFiles[value] != null ? sourceFiles[value] : sourceFiles[value] = {
          type: 'file',
          path: value,
          name: fileName,
          stats: {
            lines: {
              found: {}
            },
            branches: {
              found: {}
            },
            functions: {
              found: {}
            }
          }
        };
        break;
      case "FN":
        ref3 = value.split(',').map(trim), lineNumber = ref3[0], name = ref3[1];
        functionData = (base = file.stats.functions.found)[name] != null ? base[name] : base[name] = {};
        functionData.line = parseInt(lineNumber, 10);
        break;
      case "FNDA":
        ref4 = value.split(',').map(trim), executionCount = ref4[0], name = ref4[1];
        functionData = (base1 = file.stats.functions.found)[name] != null ? base1[name] : base1[name] = {};
        functionData.hits = parseInt(executionCount, 10);
        break;
      case "FNF":
        file.stats.functions.total = parseInt(value, 10);
        break;
      case "FNH":
        file.stats.functions.hit = parseInt(value, 10);
        break;
      case "BRDA":
        ref5 = value.split(',').map(trim), lineNumber = ref5[0], blockNumber = ref5[1], branchNumber = ref5[2], taken = ref5[3];
        branch = (base2 = file.stats.branches.found)[lineNumber] != null ? base2[lineNumber] : base2[lineNumber] = {};
        branch.block = blockNumber;
        branch.branch = branchNumber;
        branch.hits = taken;
        break;
      case "BRF":
        file.stats.branches.total = parseInt(value, 10);
        break;
      case "BRH":
        file.stats.branches.hit = parseInt(value, 10);
        break;
      case "DA":
        ref6 = value.split(',').map(trim), lineNumber = ref6[0], hitCount = ref6[1];
        file.stats.lines.found[lineNumber] = parseInt(hitCount, 10);
        break;
      case "LH":
        file.stats.lines.hit = parseInt(value, 10);
        break;
      case "LF":
        file.stats.lines.total = parseInt(value, 10);
        break;
      case "end_of_record":
        summarizeSection(file.stats.functions);
        summarizeSection(file.stats.branches);
        summarizeSection(file.stats.lines);
        file = null;
    }
  }
  return {
    name: testName,
    files: sourceFiles
  };
};
